from netforce.model import Model, fields, get_model
from datetime import *
from dateutil.relativedelta import *
from netforce.access import get_active_company
from . import num2word

def fmt_thai_tax_no(tax_no):
    s=tax_no or ""
    s.replace("-","")
    if len(s)<13:
        s+=" "*(13-len(s))
    return s

class ReportThaiWHTCertif(Model):
    _inherit="report.thai.wht.certif"

    def get_report_data(self,ids,context={}):
        if not ids:
            return {}
        obj=self.browse(ids)[0]
        company_id=get_active_company()
        comp=get_model("company").browse(company_id)
        settings=get_model("settings").browse(1)
        pmt=obj.payment_id
        contact=pmt.partner_id
        data={
            "company_tax_no": fmt_thai_tax_no(settings.tax_no),
            "company_name": comp.name,
            "dept_addr": settings.default_address_id.address_text.replace("\n",", "), # XXX
            "tax_no": fmt_thai_tax_no(contact.tax_no),
            "partner_name": contact.name,
            "partner_addr": contact.default_address_id.address_text.replace("\n",", ") if contact.default_address_id else None, # XXX
            "date": datetime.strptime(pmt.date,"%Y-%m-%d").strftime("%d/%m/%Y"),
            "lines": [{}], # XXX
        }
        move=pmt.move_id
        if not move:
            raise Exception("Journal entry not found")
        base={}
        tax={}
        contact_type=None
        wht_no=None
        for line in move.lines:
            comp=line.tax_comp_id
            if not comp:
                continue
            if comp.type!="wht" or comp.trans_type!="in":
                continue
            if not wht_no:
                wht_no=line.tax_no
            else:
                if wht_no!=line.tax_no:
                    raise Exception("Multiple WHT numbers for same payment")
            if not contact_type:
                contact_type=comp.contact_type
            else:
                if contact_type!=comp.contact_type:
                    raise Exception("Different WHT contact types for same payment")
            exp_code=comp.sequence or "5"
            exp_code=exp_code.replace(".","_")
            print('sequence ', exp_code)
            #if comp.exp_type=="salary":
                #exp_code="1"
            #elif comp.exp_type=="commission":
                #exp_code="2"
            #elif comp.exp_type=="royalty":
                #exp_code="3"
            #elif comp.exp_type=="interest":
                #exp_code="4"
            #elif comp.exp_type in ("rental","service","transport","advert"):
                #exp_code="5"
            #else:
                #exp_code="6"
            if exp_code=="6":
                data["desc"]=comp.description
            base.setdefault(exp_code,0)
            tax.setdefault(exp_code,0)
            base[exp_code]+=line.tax_base
            tax[exp_code]+=line.credit-line.debit
        if not wht_no:
            raise Exception("WHT number not found")
        data["number"]=wht_no
        if contact_type=="individual":
            data["num_user1"]="x"
            data["num_user2"]=""
        elif contact_type=="company":
            data["num_user1"]=""
            data["num_user2"]="x"
        for exp_code,amt in base.items():
            data["amt_"+exp_code]=amt
        for exp_code,amt in tax.items():
            data["tax_"+exp_code]=amt
        data["sum_amt"]=sum(base.values())
        data["sum_tax"]=sum(tax.values())
        data["total_word"]=num2word.num2word_th(data["sum_tax"],l='th')
        return data

ReportThaiWHTCertif.register()
